@@ -9,7 +9,7 @@
 class Horde_SessionHandler_Storage_Base extends Horde_Test_Case
 {
     protected static $handler;
-    protected static $dir;
+    public static $dir;
 
     protected function _write()
     {
@@ -68,11 +68,6 @@ class Horde_SessionHandler_Storage_Base extends Horde_Test_Case
                             self::$handler->getSessionIDs());
     }
 
-    public static function setUpBeforeClass()
-    {
-        self::$dir = Horde_Util::createTempDir();
-    }
-
     public static function tearDownAfterClass()
     {
         self::$handler = null;
