@@ -15,29 +15,29 @@ require_once dirname(__FILE__) . '/Base.php';
  */
 class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Storage_Base
 {
+    /**
+     * @runInSeparateProcess
+     */
     public function testWrite()
     {
-        session_name('sessionname');
-        session_id('sessionid');
-        session_start();
-        $this->assertEmpty($_SESSION);
-        $_SESSION['sessiondata'] = 'foo';
-        session_write_close();
+        $this->_write();
     }
 
     /**
-     * @depends testWrite
+     * @runInSeparateProcess
      */
     public function testRead()
     {
+        $this->_write();
         $this->assertEquals('sessiondata|s:3:"foo";', self::$handler->read('sessionid'));
     }
 
     /**
-     * @depends testWrite
+     * @runInSeparateProcess
      */
     public function testReopen()
     {
+        $this->_write();
         session_write_close();
         session_name('sessionname');
         session_id('sessionid');
@@ -47,10 +47,11 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
     }
 
     /**
-     * @depends testWrite
+     * @runInSeparateProcess
      */
     public function testList()
     {
+        $this->_write();
         session_write_close();
         session_name('sessionname');
         session_id('sessionid2');
@@ -69,10 +70,11 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
     }
 
     /**
-     * @depends testList
+     * @runInSeparateProcess
      */
     public function testDestroy()
     {
+        $this->testList();
         session_name('sessionname');
         session_id('sessionid2');
         session_start();
@@ -86,10 +88,11 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
     }
 
     /**
-     * @depends testDestroy
+     * @runInSeparateProcess
      */
     public function testGc()
     {
+        $this->testDestroy();
         $this->probability = ini_get('session.gc_probability');
         $this->divisor     = ini_get('session.gc_divisor');
         $this->maxlifetime = ini_get('session.gc_maxlifetime');
@@ -102,24 +105,22 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
                             self::$handler->getSessionIDs());
     }
 
+    protected function _write()
+    {
+        session_name('sessionname');
+        session_id('sessionid');
+        session_start();
+        $this->assertEmpty($_SESSION);
+        $_SESSION['sessiondata'] = 'foo';
+        session_write_close();
+    }
+
     public static function setUpBeforeClass()
     {
         parent::setUpBeforeClass();
-        session_cache_limiter('');
-        ini_set('session.use_cookies', 0);
-        ini_set('session.save_path', self::$dir);
         self::$handler = new Horde_SessionHandler_Storage_Builtin(array('path' => self::$dir));
     }
 
-    public function tearDown()
-    {
-        if (isset($this->probability)) {
-            ini_set('session.gc_probability', $this->probability);
-            ini_set('session.gc_divisor', $this->divisor);
-            ini_set('session.gc_maxlifetime', $this->maxlifetime);
-        }
-    }
-
     /**
      * @todo Rely on session_status() in H6.
      */
@@ -133,7 +134,6 @@ class Horde_SessionHandler_Storage_BuiltinTest extends Horde_SessionHandler_Stor
              session_id())) {
             session_destroy();
         }
-        session_name(ini_get('session.name'));
     }
 
 }
